@@ -28,8 +28,9 @@ def read_extract(file_name: str) -> pd.DataFrame:
   extension = os.path.splitext(file_name)[1].lower()
   print(f"extension detected: {extension}")
 
-  if extension == '.xlsx':
-    df = read_excel(file_name)
+  if extension in ['.xlsx', '.xls']:
+    engine = 'openpyxl' if extension == '.xlsx' else 'xlrd'
+    df = read_excel(file_name, engine)
     pass
   else:
     df = read_csv(file_name)
@@ -38,9 +39,18 @@ def read_extract(file_name: str) -> pd.DataFrame:
   return df
 
 
-def read_excel(file_name: str) -> pd.DataFrame:
-  # TODO: read spreadsheet
-  raise Exception(f"could not extract file: {file_name}")
+def read_excel(file_name: str, engine: str) -> pd.DataFrame:
+  for n in range(5):
+    df = pd.read_excel(
+      file_name,
+      engine=engine,
+      header=n,
+      dtype=str,  
+      index_col=False)
+    if "Unnamed: 3" not in df.columns:
+      print(f"found headers at row {n} (zero-indexed)")
+      break
+  return df
 
 
 def read_csv(file_name: str) -> pd.DataFrame:
